@@ -1,4 +1,4 @@
-/* pcap-encap.h
+/** @file
  * Declarations for routines to handle pcap/pcapng linktype values
  *
  * Wiretap Library
@@ -21,7 +21,7 @@ extern "C" {
 #endif /* __cplusplus */
 
 WS_DLL_PUBLIC int wtap_pcap_encap_to_wtap_encap(int encap);
-WS_DLL_PUBLIC int wtap_wtap_encap_to_pcap_encap(int encap);
+int wtap_wtap_encap_to_pcap_encap(int encap);
 WS_DLL_PUBLIC gboolean wtap_encap_requires_phdr(int encap);
 
 #ifdef __cplusplus
